<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="vanished">Poista</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">Koko näyttö</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">Diaesitys</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Vie</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopioi</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Suosikki</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Käännä myötäpäivään</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Käännä vastapäivään</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Aseta taustakuvaksi</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Näytä tiedostohallinnassa</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">Kuvan tiedot</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="vanished">Videon tiedot</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">Palauta</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Nimeämätön</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Luo</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Uusi albumi</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Haluatko varmasti poistaa tämän albumin?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Roskakori</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Suosikit</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Tuonti</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Roskakori</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Suosikit</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>tai vedä valokuvia tähän</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Tuo kaikki</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Tuo kohteeseen:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Tuonti</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Järjestelmälevy</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galleria</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Levy varattu, sitä ei voi poistaa</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Uusi albumi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ohita</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Ladataan...</translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation>Tiedostot poistetaan pysyvästi niille annetun päivän jälkeen</translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Albumi</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Korvaa</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Vie</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Asiakirjat</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Lataukset</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videot</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musiikki</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Tallenna nimellä:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Muoto:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Laatu:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Valitse toinen hakemisto</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Tiedostonimi ei voi olla tyhjä</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>on jo olemassa, haluatko korvata?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ruudunkaappaus</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Piirrä</translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation>(kopio)</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 asema</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Tyhjä %1 levy</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 salattu</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Asema</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Vie kuvat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Poistaminen...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Palautetaan...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation>Haluatko varmasti poistaa tämän tiedoston pysyvästi?</translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation>Et voi enää palauttaa sitä</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation>Haluatko varmasti poistaa %1 tiedostoa pysyvästi?</translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation>Et voi enää palauttaa niitä</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation>Haluatko varmasti poistaa tämän tiedoston paikallisesti?</translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation>Voit palauttaa sen roskakoriin</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation>Haluatko varmasti poistaa %1 tiedostoa paikallisesti?</translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation>Voit palauttaa ne roskakoriin</translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Perustiedot</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Yksityiskohdat</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Kuvan tiedot</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Tuonti</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>1 kuva</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n kuvaa</numerusform>
            <numerusform>%n kuvaa</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n videota</numerusform>
            <numerusform>%n videota</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n kohdetta</numerusform>
            <numerusform>%n kohdetta</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Tuo valokuvia ja videoita</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>tai vedä ne tänne</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Kaikki kuvat ja videot</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Kuvia tai videoita ei löytynyt</translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Diaesitys</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeä</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Vie</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Laite</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galleria</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albumit</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Uusi albumi</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>Albumi on kätevä valokuvien, videoiden katseluun, sekä järjestämiseen.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Koko näyttö</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näytä tiedostohallinnassa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaesitys</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Aseta taustakuvaksi</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Käännä myötäpäivään</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Käännä vastapäivään</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Edellinen</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Seuraava</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikki</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Inhokki</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Nimeä albumi</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Albumi “%1” poistettu</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>&quot;%1&quot; lisättiin onnistuneesti</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Tuonti onnistui</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Tuonti epäonnistui</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Vienti epäonnistui</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Vienti onnistui</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Kaikki kuvat</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Aika</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albumit</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Poistu koko näytöstä/diaesityksestä</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näytä pikakuvakkeet</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Valitse kaikki</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Lähennä</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Loitonna</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Uusi albumi</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Sivu ylös</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Sivu alas</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Tuodaan...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Kaikki kuvat ja videot</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Tuo valokuvia ja videoita</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Kuvia tai videoita ei löytynyt</translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation>Vie kuvat</translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation>Tuo valokuvia/videoita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation>Valokuva-/videotiedot</translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation>Tuo valokuvia ja videoita</translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation>Tuo kansiot</translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation>Tuonti keskeytetty</translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation>Tätä polkua ei voi lisätä, kokeile toista</translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation>Polku on jo olemassa</translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation>%1 tiedoston palautus epäonnistui: tiedostonimi liian pitkä</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Salama</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Mitat</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Kuvauspäivä</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Muokattu</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Valotustila</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Valotusohjelma</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Valotusaika</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Aukko</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Polttoväli</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Suurin aukko</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mittaustila</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Valkotasapaino</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Salamakorjaus</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kameramalli</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Linssimalli</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Väriavaruus</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tunniste</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>Ei tuloksia</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Järjestelmälevy</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Valitse</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Irti</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%3/%2/%1</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Tuotu </translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %3-%2-%1 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Tuotu </translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Valitse kaikki</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>Poista valinnat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Palauta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videot</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>Ei tuloksia</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikki</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Käännä vastapäivään</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Käännä myötäpäivään</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Tuodaan...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>%1/%2 kohdetta tuotu</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>%1/%2 kohdetta poistettu</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>%1 kohdetta tuotu, %2 epäonnistui</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>1 kuva valittuna</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>1 video valittuna</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>Kuva/video on jo olemassa</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation>
            <numerusform>%n kuvaa valittuna</numerusform>
            <numerusform>%n kuvaa valittuna</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation>
            <numerusform>%n videota valittuna</numerusform>
            <numerusform>%n videota valittuna</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation>
            <numerusform>%n kohdetta valittuna</numerusform>
            <numerusform>%n kohdetta valittuna</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>%1 kohdetta tuotu, %2 oli jo olemassa</translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Ei hakutuloksia</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Diaesitys</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Hakutuloksia</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>1 kuva löytyi</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation>
            <numerusform>%n videota löytyi</numerusform>
            <numerusform>%n videota löytyi</numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>1 video löytyi</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation>
            <numerusform>%n kohdetta löytyi</numerusform>
            <numerusform>%n kohdetta löytyi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation>
            <numerusform>%n kuvaa löydetty</numerusform>
            <numerusform>%n kuvaa löydetty</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1 kuva</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n kuvaa</numerusform>
            <numerusform>%n kuvaa</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n videota</numerusform>
            <numerusform>%n videota</numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation>Tuodaan: %1</translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation>Viedään: %1</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Koko näyttö</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Vie</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Suosikki</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Inhokki</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Käännä myötäpäivään</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Käännä vastapäivään</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näytä tiedostohallinnassa</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Aseta taustakuvaksi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaesitys</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Kuvan tiedot</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Lisää albumiin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Poista albumista</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Palauta</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Uusi albumi</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tulosta</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Videon tiedot</translation>
    </message>
    <message>
        <source>days</source>
        <translation>päivää</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>1 kuva</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n kuvaa</numerusform>
            <numerusform>%n kuvaa</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n videota</numerusform>
            <numerusform>%n videota</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n kohdetta</numerusform>
            <numerusform>%n kohdetta</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Perustiedot</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>Koodekin tiedot</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>Äänen tiedot</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>Videokoodekin tunnus</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>Videokoodekin nopeus</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>Mittasuhde</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resoluutio</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>Äänikoodekin tunnus</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>Äänikoodekin nopeus</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation>Ääni nro</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Kanavat</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanava</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>Näytteenotto</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Muokattu</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Kesto</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Polku</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Videon tiedot</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Kuvauspäivä</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
</context>
</TS>
